help:
	@echo try targets as:
	@echo   cl
	@echo   cl-pgo
	@echo   icl
	@echo   icl-pgo


# Compile Options
#
# /DNDEBUG (DEBUG)  builds release (debug) version of Bonanza.
# /DMINIMUM         disables some auxiliary functions that are not necessary to
#                   play a game, e.g., book composition and optimization of
#                   evaluation function.
# /DTLP             enables thread-level parallel search.
# /DMPV             enables multi-PV search.
# /DCSA_LAN         enables bonanza to talk CSA Shogi TCP/IP protcol.
# /DDEKUNOBOU       enables dekunobou interface (avairable only for Windows).
# /DCSASHOGI        builds an engine for CSA Shogi (avairable only for
#                   Windows).
# /DNO_LOGGING      suppresses dumping log files.

FLAG = /DNDEBUG /DMINIMUM /DTLP /DMPV /DCSASHOGI /DNO_LOGGING

OBJS = data.obj main.obj io.obj proce.obj ini.obj utility.obj attack.obj\
       gencap.obj gennocap.obj gendrop.obj genevasn.obj mate3.obj genchk.obj\
       movgenex.obj makemove.obj unmake.obj time.obj csa.obj valid.obj\
       next.obj search.obj searchr.obj book.obj iterate.obj quiesrch.obj\
       swap.obj evaluate.obj root.obj hash.obj mate1ply.obj bitop.obj\
       rand.obj learn1.obj learn2.obj evaldiff.obj problem.obj ponder.obj\
       thread.obj dek.obj sckt.obj debug.obj

cl:
	$(MAKE) -f Makefile.vs bonanza.exe CC="cl" LD="link"\
		CFLAGS="$(FLAG) /MT /W4 /nologo /O2 /Ob2 /Gr /GS- /GL"\
		LDFLAGS="/NOLOGO /out:bonanza.exe /LTCG"

cl-pgo:
	$(MAKE) -f Makefile.vs clean
	$(MAKE) -f Makefile.vs bonanza.exe CC="cl" LD="link"\
		CFLAGS="$(FLAG) /MT /W4 /nologo /O2 /Ob2 /Gr /GS- /GL"\
		LDFLAGS="/NOLOGO /out:bonanza.exe /LTCG:PGI"
	$(MAKE) -f Makefile.vs pgo-run
	del bonanza.exe
	$(MAKE) -f Makefile.vs bonanza.exe LD="link"\
		LDFLAGS="/NOLOGO /out:bonanza.exe /LTCG:PGO"

icl:
	$(MAKE) -f Makefile.vs bonanza.exe CC="icl" LD="icl"\
		CFLAGS="/nologo $(FLAG) /Wall /O3 /Qipo /Gr"\
		LDFLAGS="/nologo /Febonanza.exe"

icl-pgo:
	$(MAKE) -f Makefile.vs clean
	$(MAKE) -f Makefile.vs bonanza.exe CC="icl" LD="icl"\
		CFLAGS="/nologo $(FLAG) /Wall /O3 /Qprof-gen /Gr"\
		LDFLAGS="/nologo /Febonanza.exe /Qprof-gen"
	$(MAKE) -f Makefile.vs pgo-run
	del *.obj
	$(MAKE) -f Makefile.vs bonanza.exe CC="icl" LD="icl"\
		CFLAGS="/nologo $(FLAG) /Wall /O3 /Qipo /Qprof-use /Gr"\
		LDFLAGS="/nologo /Febonanza.exe /Qprof-use"

pgo-run:
#	echo learn no-ini 5 32 1   >> runprof
	echo limit time extendable >> runprof
	echo limit time 0 3        >> runprof
	echo tlp num 2             >> runprof
	echo problem 256           >> runprof
	echo quit                  >> runprof
	bonanza.exe                 < runprof

bonanza.exe : $(OBJS) bonanza.res
	$(LD) $(LDFLAGS) $(OBJS) bonanza.res User32.lib Ws2_32.lib

$(OBJS)  : shogi.h param.h

bonanza.res : bonanza.rc bonanza.ico
	rc /fobonanza.res bonanza.rc

.c.obj :
	$(CC) $(CFLAGS) /c $*.c

clean :
	del /q runprof
        del /q *.pdb
        del /q *.ilk
        del /q *.pgd
        del /q *.pgc
        del /q *.dyn
	del /q *.obj
	del /q *.res
	del /q *.s 
	del /q bonanza.exe
